@@ -46,7 +46,7 @@ class Command(BaseCommand):
                 logger.info("Is finishing e-mail.")
                 source.active = False
             self.process_source(source)
-            read_date = datetime.datetime.utcnow().replace(utc)
+            read_date = datetime.datetime.utcnow().replace(tzinfo=utc)
             message.read = read_date
             message.save()
             logger.debug("Marked as read.")
@@ -61,9 +61,7 @@ class Command(BaseCommand):
         points = self.get_points(document)
         route_name = self.get_route_name(document)
 
-        max_date = LocationSnapshot.objects\
-                .filter(source=source)\
-                .aggregate(max_date=Max('date'))['max_date']
+        max_date = None
         for key_name, data_point in points.items():
             if key_name not in source.data['known_points'].keys():
                 logger.debug("%s not in %s" % (
